@@ -13,7 +13,7 @@ CAMERA_MESSAGES = [
     "OFFLINE",
     "ONLINE",
 ]
-EVENT_MESSAGES = ["TRIGGER_M", "FILE", "MOTION"]
+EVENT_MESSAGES = ["TRIGGER_M", "FILE", "MOTION", "CLASSIFY"]
 
 RECORDING_TYPE_ACTION = "action"
 RECORDING_TYPE_MOTION = "on_motion"
